@@ -7,6 +7,7 @@ from time import time
 import logging
 import plotly
 from pathlib import Path
+from itertools import chain
 
 
 class Region(object):
@@ -51,6 +52,10 @@ def make_windows(full_window, max_size=1e6, fasta=None):
         return [reg]
 
 
+def flatten(nested_list):
+    return list(chain.from_iterable(nested_list))
+
+
 def get_args():
     parser = ArgumentParser(description="plotting nanopolish methylation calls or frequency")
     parser.add_argument("-v", "--version",
@@ -93,6 +98,10 @@ def get_args():
                         help="Control the size of dots in the per read plots",
                         type=int,
                         default=4)
+    parser.add_argument("--minqual",
+                        help="The minimal phred quality to show [for bam/cram input only]",
+                        type=int,
+                        default=20)
     parser.add_argument("--example",
                         action="store_true",
                         help="Show example command and exit.")
@@ -178,7 +187,7 @@ def file_sniffer(filename):
     if not Path(filename).is_file():
         sys.exit(f"\n\nERROR: File {filename} does not exist, please check the path!\n")
     if is_cram_file(filename):
-        return "ont-cram"
+        return "cram"
     if is_bam_file(filename):
         return "bam"
     if is_gz_file(filename):
